@@ -5,7 +5,7 @@
 */
 
 #pragma once
-
+#include "kcmutils_version.h"
 #include <KCModule>
 #include <QVariant>
 
@@ -15,8 +15,11 @@ class KCMAkregatorSecurityConfig : public KCModule
 {
     Q_OBJECT
 public:
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     explicit KCMAkregatorSecurityConfig(QWidget *parent, const QVariantList &args);
-
+#else
+    explicit KCMAkregatorSecurityConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
+#endif
 private:
     QWidget *const m_widget;
 };
